package de.assono;

import java.io.IOException;
import java.io.PrintWriter;
import java.util.Date;

import javax.servlet.Servlet;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import lotus.domino.DateTime;
import lotus.domino.NotesException;
import lotus.domino.NotesFactory;
import lotus.domino.Session;

/**
 * This class implements a simple servlet for an external (non-Domino)
 * application server.
 * 
 * @author Thomas Bahn <tbahn@assono.de>
 * @version 2007-01-07
 */
public class ExternalServlet extends HttpServlet implements Servlet {

	/**
	 * since this class implements java.io.Serializable, it should have a serial
	 * version id (by convention).
	 */
	private static final long serialVersionUID = 1L;

	/**
	 * private Notes session, which is initialized only once.
	 */
	private Session session = null;

	/**
	 * initializes the servlet by creating a Notes session.
	 * 
	 * This method is called by the servlet container.
	 * 
	 * @see javax.servlet.GenericServlet#init()
	 */
	public void init() throws ServletException {
		super.init();

		try {
			this.session = NotesFactory.createSession("127.0.0.1");

		} catch (NotesException ne) {
			throw new ServletException("NotesException occured:"
					+ "\r\nException ID:\t" + ne.id
					+ "\r\nException description:\t" + ne.text);
		}
	}

	/**
	 * destroys the servlet.
	 * 
	 * This method is called by the servlet container.
	 * 
	 * @see javax.servlet.GenericServlet#destroy()
	 */
	public void destroy() {
		super.destroy();

		try {
			if (this.session != null) // recycle session if defined
				this.session.recycle();

		} catch (NotesException ne) {
			throw new RuntimeException("NotesException occured:"
					+ "\r\nException ID:\t" + ne.id
					+ "\r\nException description:\t" + ne.text, ne);
		}
	}

	/**
	 * prints current date and time, converted to Greenwich Mean Time into the
	 * response.
	 * 
	 * @param request
	 *            request as send by the browser.
	 * @param response
	 *            response to send to the browser.
	 * 
	 * @see javax.servlet.http.HttpServlet#doGet(javax.servlet.http.HttpServletRequest,
	 *      javax.servlet.http.HttpServletResponse)
	 */
	protected void doGet(HttpServletRequest request,
			HttpServletResponse response) throws ServletException, IOException {
		response.setContentType("text/plain");
		PrintWriter writer = response.getWriter();

		try {
			// print the current date and time to the writer and recycle the
			// DateTime object.
			DateTime dt = session.createDateTime(new Date());
			writer.print(dt.getGMTTime());
			dt.recycle();

		} catch (NotesException ne) {
			throw new ServletException("NotesException occured:"
					+ "\r\nException ID:\t" + ne.id
					+ "\r\nException description:\t" + ne.text);
		}
	}
}
