package de.assono;

import java.io.IOException;
import java.io.PrintWriter;
import java.util.Date;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import lotus.domino.DateTime;
import lotus.domino.NotesException;
import lotus.domino.NotesFactory;
import lotus.domino.NotesThread;
import lotus.domino.Session;

/**
 * This class implements a simple servlet for the Domino servlet engine.
 * 
 * @author Thomas Bahn <tbahn@assono.de>
 * @version 2007-01-07
 */
public class InternalServlet extends HttpServlet {

	/**
	 * since this class implements java.io.Serializable, it should have a serial
	 * version id (by convention).
	 */
	private static final long serialVersionUID = 1L;

	/**
	 * prints current date and time, converted to Greenwich Mean Time into the
	 * response.
	 * 
	 * @param request
	 *            request as send by the browser.
	 * @param response
	 *            response to send to the browser.
	 * 
	 * @see javax.servlet.http.HttpServlet#doGet(javax.servlet.http.HttpServletRequest,
	 *      javax.servlet.http.HttpServletResponse)
	 */
	protected void doGet(HttpServletRequest request,
			HttpServletResponse response) throws ServletException, IOException {

		response.setContentType("text/plain");
		PrintWriter writer = response.getWriter();

		try {
			NotesThread.sinitThread();
			Session session = NotesFactory.createSession();

			DateTime dt = session.createDateTime(new Date());
			writer.print(dt.getGMTTime());
			dt.recycle();

			session.recycle();

		} catch (NotesException ne) {
			throw new ServletException("NotesException occured:"
					+ "\r\nException ID:\t" + ne.id
					+ "\r\nException description:\t" + ne.text);
		} finally {
			NotesThread.stermThread();
		}
	}
}
